@@ -1,9 +1,11 @@
 package Sah::Schema::latin_letter;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-23'; # DATE
+our $DATE = '2022-06-05'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $schema = [str => {
     summary => 'Latin letter, i.e. A-Z or a-z',
@@ -13,8 +15,9 @@ our $schema = [str => {
     examples => [
         {value=>'', valid=>0},
         {value=>'A', valid=>1},
-        {value=>'AB', valid=>0},
-        {value=>'1', valid=>0},
+        {value=>'AB', valid=>0, summary=>'Multiple letters'},
+        {value=>'1', valid=>0, summary=>'Non-letter'},
+        {value=>';', valid=>0, summary=>'Non-letter'},
     ],
 
 }];
@@ -34,7 +37,7 @@ Sah::Schema::latin_letter - Latin letter, i.e. A-Z or a-z
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::latin_letter (from Perl distribution Sah-Schemas-Str), released on 2021-07-23.
+This document describes version 0.004 of Sah::Schema::latin_letter (from Perl distribution Sah-Schemas-Str), released on 2022-06-05.
 
 =head1 SYNOPSIS
 
@@ -64,8 +67,7 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package
-   MyApp;
+ package MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -85,10 +87,9 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package
-   main;
+ package main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -105,9 +106,11 @@ Sample data:
 
  "A"  # valid
 
- "AB"  # INVALID
+ "AB"  # INVALID (Multiple letters)
 
- 1  # INVALID
+ 1  # INVALID (Non-letter)
+
+ ";"  # INVALID (Non-letter)
 
 =head1 HOMEPAGE
 
@@ -117,6 +120,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Str>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Str>
@@ -125,15 +156,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
