@@ -1,9 +1,11 @@
 package Sah::Schema::str_or_aos1;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-23'; # DATE
+our $DATE = '2022-06-05'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $schema = [any => {
     summary => 'String or array (1+ length) of (defined) string',
@@ -39,7 +41,7 @@ Sah::Schema::str_or_aos1 - String or array (1+ length) of (defined) string
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2021-07-23.
+This document describes version 0.004 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2022-06-05.
 
 =head1 SYNOPSIS
 
@@ -69,8 +71,7 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package
-   MyApp;
+ package MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -90,10 +91,9 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package
-   main;
+ package main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -128,6 +128,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Str>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Str>
@@ -136,15 +164,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
